# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class DataCenterEntities(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'lans': 'Lans',

        'loadbalancers': 'Loadbalancers',

        'natgateways': 'NatGateways',

        'networkloadbalancers': 'NetworkLoadBalancers',

        'servers': 'Servers',

        'volumes': 'Volumes',
    }

    attribute_map = {

        'lans': 'lans',

        'loadbalancers': 'loadbalancers',

        'natgateways': 'natgateways',

        'networkloadbalancers': 'networkloadbalancers',

        'servers': 'servers',

        'volumes': 'volumes',
    }

    def __init__(self, lans=None, loadbalancers=None, natgateways=None, networkloadbalancers=None, servers=None, volumes=None, local_vars_configuration=None):  # noqa: E501
        """DataCenterEntities - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._lans = None
        self._loadbalancers = None
        self._natgateways = None
        self._networkloadbalancers = None
        self._servers = None
        self._volumes = None
        self.discriminator = None

        if lans is not None:
            self.lans = lans
        if loadbalancers is not None:
            self.loadbalancers = loadbalancers
        if natgateways is not None:
            self.natgateways = natgateways
        if networkloadbalancers is not None:
            self.networkloadbalancers = networkloadbalancers
        if servers is not None:
            self.servers = servers
        if volumes is not None:
            self.volumes = volumes


    @property
    def lans(self):
        """Gets the lans of this DataCenterEntities.  # noqa: E501


        :return: The lans of this DataCenterEntities.  # noqa: E501
        :rtype: Lans
        """
        return self._lans

    @lans.setter
    def lans(self, lans):
        """Sets the lans of this DataCenterEntities.


        :param lans: The lans of this DataCenterEntities.  # noqa: E501
        :type lans: Lans
        """

        self._lans = lans

    @property
    def loadbalancers(self):
        """Gets the loadbalancers of this DataCenterEntities.  # noqa: E501


        :return: The loadbalancers of this DataCenterEntities.  # noqa: E501
        :rtype: Loadbalancers
        """
        return self._loadbalancers

    @loadbalancers.setter
    def loadbalancers(self, loadbalancers):
        """Sets the loadbalancers of this DataCenterEntities.


        :param loadbalancers: The loadbalancers of this DataCenterEntities.  # noqa: E501
        :type loadbalancers: Loadbalancers
        """

        self._loadbalancers = loadbalancers

    @property
    def natgateways(self):
        """Gets the natgateways of this DataCenterEntities.  # noqa: E501


        :return: The natgateways of this DataCenterEntities.  # noqa: E501
        :rtype: NatGateways
        """
        return self._natgateways

    @natgateways.setter
    def natgateways(self, natgateways):
        """Sets the natgateways of this DataCenterEntities.


        :param natgateways: The natgateways of this DataCenterEntities.  # noqa: E501
        :type natgateways: NatGateways
        """

        self._natgateways = natgateways

    @property
    def networkloadbalancers(self):
        """Gets the networkloadbalancers of this DataCenterEntities.  # noqa: E501


        :return: The networkloadbalancers of this DataCenterEntities.  # noqa: E501
        :rtype: NetworkLoadBalancers
        """
        return self._networkloadbalancers

    @networkloadbalancers.setter
    def networkloadbalancers(self, networkloadbalancers):
        """Sets the networkloadbalancers of this DataCenterEntities.


        :param networkloadbalancers: The networkloadbalancers of this DataCenterEntities.  # noqa: E501
        :type networkloadbalancers: NetworkLoadBalancers
        """

        self._networkloadbalancers = networkloadbalancers

    @property
    def servers(self):
        """Gets the servers of this DataCenterEntities.  # noqa: E501


        :return: The servers of this DataCenterEntities.  # noqa: E501
        :rtype: Servers
        """
        return self._servers

    @servers.setter
    def servers(self, servers):
        """Sets the servers of this DataCenterEntities.


        :param servers: The servers of this DataCenterEntities.  # noqa: E501
        :type servers: Servers
        """

        self._servers = servers

    @property
    def volumes(self):
        """Gets the volumes of this DataCenterEntities.  # noqa: E501


        :return: The volumes of this DataCenterEntities.  # noqa: E501
        :rtype: Volumes
        """
        return self._volumes

    @volumes.setter
    def volumes(self, volumes):
        """Sets the volumes of this DataCenterEntities.


        :param volumes: The volumes of this DataCenterEntities.  # noqa: E501
        :type volumes: Volumes
        """

        self._volumes = volumes
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DataCenterEntities):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DataCenterEntities):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class ResourceLimits(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'cores_per_contract': 'int',

        'cores_per_server': 'int',

        'cores_provisioned': 'int',

        'das_volume_provisioned': 'int',

        'hdd_limit_per_contract': 'int',

        'hdd_limit_per_volume': 'int',

        'hdd_volume_provisioned': 'int',

        'k8s_cluster_limit_total': 'int',

        'k8s_clusters_provisioned': 'int',

        'nat_gateway_limit_total': 'int',

        'nat_gateway_provisioned': 'int',

        'nlb_limit_total': 'int',

        'nlb_provisioned': 'int',

        'ram_per_contract': 'int',

        'ram_per_server': 'int',

        'ram_provisioned': 'int',

        'reservable_ips': 'int',

        'reserved_ips_in_use': 'int',

        'reserved_ips_on_contract': 'int',

        'ssd_limit_per_contract': 'int',

        'ssd_limit_per_volume': 'int',

        'ssd_volume_provisioned': 'int',
    }

    attribute_map = {

        'cores_per_contract': 'coresPerContract',

        'cores_per_server': 'coresPerServer',

        'cores_provisioned': 'coresProvisioned',

        'das_volume_provisioned': 'dasVolumeProvisioned',

        'hdd_limit_per_contract': 'hddLimitPerContract',

        'hdd_limit_per_volume': 'hddLimitPerVolume',

        'hdd_volume_provisioned': 'hddVolumeProvisioned',

        'k8s_cluster_limit_total': 'k8sClusterLimitTotal',

        'k8s_clusters_provisioned': 'k8sClustersProvisioned',

        'nat_gateway_limit_total': 'natGatewayLimitTotal',

        'nat_gateway_provisioned': 'natGatewayProvisioned',

        'nlb_limit_total': 'nlbLimitTotal',

        'nlb_provisioned': 'nlbProvisioned',

        'ram_per_contract': 'ramPerContract',

        'ram_per_server': 'ramPerServer',

        'ram_provisioned': 'ramProvisioned',

        'reservable_ips': 'reservableIps',

        'reserved_ips_in_use': 'reservedIpsInUse',

        'reserved_ips_on_contract': 'reservedIpsOnContract',

        'ssd_limit_per_contract': 'ssdLimitPerContract',

        'ssd_limit_per_volume': 'ssdLimitPerVolume',

        'ssd_volume_provisioned': 'ssdVolumeProvisioned',
    }

    def __init__(self, cores_per_contract=None, cores_per_server=None, cores_provisioned=None, das_volume_provisioned=None, hdd_limit_per_contract=None, hdd_limit_per_volume=None, hdd_volume_provisioned=None, k8s_cluster_limit_total=None, k8s_clusters_provisioned=None, nat_gateway_limit_total=None, nat_gateway_provisioned=None, nlb_limit_total=None, nlb_provisioned=None, ram_per_contract=None, ram_per_server=None, ram_provisioned=None, reservable_ips=None, reserved_ips_in_use=None, reserved_ips_on_contract=None, ssd_limit_per_contract=None, ssd_limit_per_volume=None, ssd_volume_provisioned=None, local_vars_configuration=None):  # noqa: E501
        """ResourceLimits - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._cores_per_contract = None
        self._cores_per_server = None
        self._cores_provisioned = None
        self._das_volume_provisioned = None
        self._hdd_limit_per_contract = None
        self._hdd_limit_per_volume = None
        self._hdd_volume_provisioned = None
        self._k8s_cluster_limit_total = None
        self._k8s_clusters_provisioned = None
        self._nat_gateway_limit_total = None
        self._nat_gateway_provisioned = None
        self._nlb_limit_total = None
        self._nlb_provisioned = None
        self._ram_per_contract = None
        self._ram_per_server = None
        self._ram_provisioned = None
        self._reservable_ips = None
        self._reserved_ips_in_use = None
        self._reserved_ips_on_contract = None
        self._ssd_limit_per_contract = None
        self._ssd_limit_per_volume = None
        self._ssd_volume_provisioned = None
        self.discriminator = None

        self.cores_per_contract = cores_per_contract
        self.cores_per_server = cores_per_server
        self.cores_provisioned = cores_provisioned
        self.das_volume_provisioned = das_volume_provisioned
        self.hdd_limit_per_contract = hdd_limit_per_contract
        self.hdd_limit_per_volume = hdd_limit_per_volume
        self.hdd_volume_provisioned = hdd_volume_provisioned
        self.k8s_cluster_limit_total = k8s_cluster_limit_total
        self.k8s_clusters_provisioned = k8s_clusters_provisioned
        self.nat_gateway_limit_total = nat_gateway_limit_total
        self.nat_gateway_provisioned = nat_gateway_provisioned
        self.nlb_limit_total = nlb_limit_total
        self.nlb_provisioned = nlb_provisioned
        self.ram_per_contract = ram_per_contract
        self.ram_per_server = ram_per_server
        self.ram_provisioned = ram_provisioned
        self.reservable_ips = reservable_ips
        self.reserved_ips_in_use = reserved_ips_in_use
        self.reserved_ips_on_contract = reserved_ips_on_contract
        self.ssd_limit_per_contract = ssd_limit_per_contract
        self.ssd_limit_per_volume = ssd_limit_per_volume
        self.ssd_volume_provisioned = ssd_volume_provisioned


    @property
    def cores_per_contract(self):
        """Gets the cores_per_contract of this ResourceLimits.  # noqa: E501

        The maximum number of CPU cores per contract.  # noqa: E501

        :return: The cores_per_contract of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._cores_per_contract

    @cores_per_contract.setter
    def cores_per_contract(self, cores_per_contract):
        """Sets the cores_per_contract of this ResourceLimits.

        The maximum number of CPU cores per contract.  # noqa: E501

        :param cores_per_contract: The cores_per_contract of this ResourceLimits.  # noqa: E501
        :type cores_per_contract: int
        """
        if self.local_vars_configuration.client_side_validation and cores_per_contract is None:  # noqa: E501
            raise ValueError("Invalid value for `cores_per_contract`, must not be `None`")  # noqa: E501

        self._cores_per_contract = cores_per_contract

    @property
    def cores_per_server(self):
        """Gets the cores_per_server of this ResourceLimits.  # noqa: E501

        The maximum number of CPU cores per server.  # noqa: E501

        :return: The cores_per_server of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._cores_per_server

    @cores_per_server.setter
    def cores_per_server(self, cores_per_server):
        """Sets the cores_per_server of this ResourceLimits.

        The maximum number of CPU cores per server.  # noqa: E501

        :param cores_per_server: The cores_per_server of this ResourceLimits.  # noqa: E501
        :type cores_per_server: int
        """
        if self.local_vars_configuration.client_side_validation and cores_per_server is None:  # noqa: E501
            raise ValueError("Invalid value for `cores_per_server`, must not be `None`")  # noqa: E501

        self._cores_per_server = cores_per_server

    @property
    def cores_provisioned(self):
        """Gets the cores_provisioned of this ResourceLimits.  # noqa: E501

        The number of CPU cores provisioned.  # noqa: E501

        :return: The cores_provisioned of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._cores_provisioned

    @cores_provisioned.setter
    def cores_provisioned(self, cores_provisioned):
        """Sets the cores_provisioned of this ResourceLimits.

        The number of CPU cores provisioned.  # noqa: E501

        :param cores_provisioned: The cores_provisioned of this ResourceLimits.  # noqa: E501
        :type cores_provisioned: int
        """
        if self.local_vars_configuration.client_side_validation and cores_provisioned is None:  # noqa: E501
            raise ValueError("Invalid value for `cores_provisioned`, must not be `None`")  # noqa: E501

        self._cores_provisioned = cores_provisioned

    @property
    def das_volume_provisioned(self):
        """Gets the das_volume_provisioned of this ResourceLimits.  # noqa: E501

        The amount of DAS disk space (in MB) in a Cube server that is currently provisioned.  # noqa: E501

        :return: The das_volume_provisioned of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._das_volume_provisioned

    @das_volume_provisioned.setter
    def das_volume_provisioned(self, das_volume_provisioned):
        """Sets the das_volume_provisioned of this ResourceLimits.

        The amount of DAS disk space (in MB) in a Cube server that is currently provisioned.  # noqa: E501

        :param das_volume_provisioned: The das_volume_provisioned of this ResourceLimits.  # noqa: E501
        :type das_volume_provisioned: int
        """
        if self.local_vars_configuration.client_side_validation and das_volume_provisioned is None:  # noqa: E501
            raise ValueError("Invalid value for `das_volume_provisioned`, must not be `None`")  # noqa: E501

        self._das_volume_provisioned = das_volume_provisioned

    @property
    def hdd_limit_per_contract(self):
        """Gets the hdd_limit_per_contract of this ResourceLimits.  # noqa: E501

        The maximum amount of disk space (in MB) that can be provided under this contract.  # noqa: E501

        :return: The hdd_limit_per_contract of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._hdd_limit_per_contract

    @hdd_limit_per_contract.setter
    def hdd_limit_per_contract(self, hdd_limit_per_contract):
        """Sets the hdd_limit_per_contract of this ResourceLimits.

        The maximum amount of disk space (in MB) that can be provided under this contract.  # noqa: E501

        :param hdd_limit_per_contract: The hdd_limit_per_contract of this ResourceLimits.  # noqa: E501
        :type hdd_limit_per_contract: int
        """
        if self.local_vars_configuration.client_side_validation and hdd_limit_per_contract is None:  # noqa: E501
            raise ValueError("Invalid value for `hdd_limit_per_contract`, must not be `None`")  # noqa: E501

        self._hdd_limit_per_contract = hdd_limit_per_contract

    @property
    def hdd_limit_per_volume(self):
        """Gets the hdd_limit_per_volume of this ResourceLimits.  # noqa: E501

        The maximum size (in MB) of an idividual hard disk volume.  # noqa: E501

        :return: The hdd_limit_per_volume of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._hdd_limit_per_volume

    @hdd_limit_per_volume.setter
    def hdd_limit_per_volume(self, hdd_limit_per_volume):
        """Sets the hdd_limit_per_volume of this ResourceLimits.

        The maximum size (in MB) of an idividual hard disk volume.  # noqa: E501

        :param hdd_limit_per_volume: The hdd_limit_per_volume of this ResourceLimits.  # noqa: E501
        :type hdd_limit_per_volume: int
        """
        if self.local_vars_configuration.client_side_validation and hdd_limit_per_volume is None:  # noqa: E501
            raise ValueError("Invalid value for `hdd_limit_per_volume`, must not be `None`")  # noqa: E501

        self._hdd_limit_per_volume = hdd_limit_per_volume

    @property
    def hdd_volume_provisioned(self):
        """Gets the hdd_volume_provisioned of this ResourceLimits.  # noqa: E501

        The amount of hard disk space (in MB) that is currently provisioned.  # noqa: E501

        :return: The hdd_volume_provisioned of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._hdd_volume_provisioned

    @hdd_volume_provisioned.setter
    def hdd_volume_provisioned(self, hdd_volume_provisioned):
        """Sets the hdd_volume_provisioned of this ResourceLimits.

        The amount of hard disk space (in MB) that is currently provisioned.  # noqa: E501

        :param hdd_volume_provisioned: The hdd_volume_provisioned of this ResourceLimits.  # noqa: E501
        :type hdd_volume_provisioned: int
        """
        if self.local_vars_configuration.client_side_validation and hdd_volume_provisioned is None:  # noqa: E501
            raise ValueError("Invalid value for `hdd_volume_provisioned`, must not be `None`")  # noqa: E501

        self._hdd_volume_provisioned = hdd_volume_provisioned

    @property
    def k8s_cluster_limit_total(self):
        """Gets the k8s_cluster_limit_total of this ResourceLimits.  # noqa: E501

        The maximum number of Kubernetes clusters that can be created under this contract.  # noqa: E501

        :return: The k8s_cluster_limit_total of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._k8s_cluster_limit_total

    @k8s_cluster_limit_total.setter
    def k8s_cluster_limit_total(self, k8s_cluster_limit_total):
        """Sets the k8s_cluster_limit_total of this ResourceLimits.

        The maximum number of Kubernetes clusters that can be created under this contract.  # noqa: E501

        :param k8s_cluster_limit_total: The k8s_cluster_limit_total of this ResourceLimits.  # noqa: E501
        :type k8s_cluster_limit_total: int
        """
        if self.local_vars_configuration.client_side_validation and k8s_cluster_limit_total is None:  # noqa: E501
            raise ValueError("Invalid value for `k8s_cluster_limit_total`, must not be `None`")  # noqa: E501

        self._k8s_cluster_limit_total = k8s_cluster_limit_total

    @property
    def k8s_clusters_provisioned(self):
        """Gets the k8s_clusters_provisioned of this ResourceLimits.  # noqa: E501

        The amount of Kubernetes clusters that is currently provisioned.  # noqa: E501

        :return: The k8s_clusters_provisioned of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._k8s_clusters_provisioned

    @k8s_clusters_provisioned.setter
    def k8s_clusters_provisioned(self, k8s_clusters_provisioned):
        """Sets the k8s_clusters_provisioned of this ResourceLimits.

        The amount of Kubernetes clusters that is currently provisioned.  # noqa: E501

        :param k8s_clusters_provisioned: The k8s_clusters_provisioned of this ResourceLimits.  # noqa: E501
        :type k8s_clusters_provisioned: int
        """
        if self.local_vars_configuration.client_side_validation and k8s_clusters_provisioned is None:  # noqa: E501
            raise ValueError("Invalid value for `k8s_clusters_provisioned`, must not be `None`")  # noqa: E501

        self._k8s_clusters_provisioned = k8s_clusters_provisioned

    @property
    def nat_gateway_limit_total(self):
        """Gets the nat_gateway_limit_total of this ResourceLimits.  # noqa: E501

        The NAT Gateway total limit.  # noqa: E501

        :return: The nat_gateway_limit_total of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._nat_gateway_limit_total

    @nat_gateway_limit_total.setter
    def nat_gateway_limit_total(self, nat_gateway_limit_total):
        """Sets the nat_gateway_limit_total of this ResourceLimits.

        The NAT Gateway total limit.  # noqa: E501

        :param nat_gateway_limit_total: The nat_gateway_limit_total of this ResourceLimits.  # noqa: E501
        :type nat_gateway_limit_total: int
        """
        if self.local_vars_configuration.client_side_validation and nat_gateway_limit_total is None:  # noqa: E501
            raise ValueError("Invalid value for `nat_gateway_limit_total`, must not be `None`")  # noqa: E501

        self._nat_gateway_limit_total = nat_gateway_limit_total

    @property
    def nat_gateway_provisioned(self):
        """Gets the nat_gateway_provisioned of this ResourceLimits.  # noqa: E501

        The NAT Gateways provisioned.  # noqa: E501

        :return: The nat_gateway_provisioned of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._nat_gateway_provisioned

    @nat_gateway_provisioned.setter
    def nat_gateway_provisioned(self, nat_gateway_provisioned):
        """Sets the nat_gateway_provisioned of this ResourceLimits.

        The NAT Gateways provisioned.  # noqa: E501

        :param nat_gateway_provisioned: The nat_gateway_provisioned of this ResourceLimits.  # noqa: E501
        :type nat_gateway_provisioned: int
        """
        if self.local_vars_configuration.client_side_validation and nat_gateway_provisioned is None:  # noqa: E501
            raise ValueError("Invalid value for `nat_gateway_provisioned`, must not be `None`")  # noqa: E501

        self._nat_gateway_provisioned = nat_gateway_provisioned

    @property
    def nlb_limit_total(self):
        """Gets the nlb_limit_total of this ResourceLimits.  # noqa: E501

        The NLB total limit.  # noqa: E501

        :return: The nlb_limit_total of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._nlb_limit_total

    @nlb_limit_total.setter
    def nlb_limit_total(self, nlb_limit_total):
        """Sets the nlb_limit_total of this ResourceLimits.

        The NLB total limit.  # noqa: E501

        :param nlb_limit_total: The nlb_limit_total of this ResourceLimits.  # noqa: E501
        :type nlb_limit_total: int
        """
        if self.local_vars_configuration.client_side_validation and nlb_limit_total is None:  # noqa: E501
            raise ValueError("Invalid value for `nlb_limit_total`, must not be `None`")  # noqa: E501

        self._nlb_limit_total = nlb_limit_total

    @property
    def nlb_provisioned(self):
        """Gets the nlb_provisioned of this ResourceLimits.  # noqa: E501

        The NLBs provisioned.  # noqa: E501

        :return: The nlb_provisioned of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._nlb_provisioned

    @nlb_provisioned.setter
    def nlb_provisioned(self, nlb_provisioned):
        """Sets the nlb_provisioned of this ResourceLimits.

        The NLBs provisioned.  # noqa: E501

        :param nlb_provisioned: The nlb_provisioned of this ResourceLimits.  # noqa: E501
        :type nlb_provisioned: int
        """
        if self.local_vars_configuration.client_side_validation and nlb_provisioned is None:  # noqa: E501
            raise ValueError("Invalid value for `nlb_provisioned`, must not be `None`")  # noqa: E501

        self._nlb_provisioned = nlb_provisioned

    @property
    def ram_per_contract(self):
        """Gets the ram_per_contract of this ResourceLimits.  # noqa: E501

        The maximum amount of RAM (in MB) that can be provisioned under this contract.  # noqa: E501

        :return: The ram_per_contract of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._ram_per_contract

    @ram_per_contract.setter
    def ram_per_contract(self, ram_per_contract):
        """Sets the ram_per_contract of this ResourceLimits.

        The maximum amount of RAM (in MB) that can be provisioned under this contract.  # noqa: E501

        :param ram_per_contract: The ram_per_contract of this ResourceLimits.  # noqa: E501
        :type ram_per_contract: int
        """
        if self.local_vars_configuration.client_side_validation and ram_per_contract is None:  # noqa: E501
            raise ValueError("Invalid value for `ram_per_contract`, must not be `None`")  # noqa: E501

        self._ram_per_contract = ram_per_contract

    @property
    def ram_per_server(self):
        """Gets the ram_per_server of this ResourceLimits.  # noqa: E501

        The maximum amount of RAM (in MB) that can be provisioned for a particular server under this contract.  # noqa: E501

        :return: The ram_per_server of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._ram_per_server

    @ram_per_server.setter
    def ram_per_server(self, ram_per_server):
        """Sets the ram_per_server of this ResourceLimits.

        The maximum amount of RAM (in MB) that can be provisioned for a particular server under this contract.  # noqa: E501

        :param ram_per_server: The ram_per_server of this ResourceLimits.  # noqa: E501
        :type ram_per_server: int
        """
        if self.local_vars_configuration.client_side_validation and ram_per_server is None:  # noqa: E501
            raise ValueError("Invalid value for `ram_per_server`, must not be `None`")  # noqa: E501

        self._ram_per_server = ram_per_server

    @property
    def ram_provisioned(self):
        """Gets the ram_provisioned of this ResourceLimits.  # noqa: E501

        The amount of RAM (in MB) provisioned under this contract.  # noqa: E501

        :return: The ram_provisioned of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._ram_provisioned

    @ram_provisioned.setter
    def ram_provisioned(self, ram_provisioned):
        """Sets the ram_provisioned of this ResourceLimits.

        The amount of RAM (in MB) provisioned under this contract.  # noqa: E501

        :param ram_provisioned: The ram_provisioned of this ResourceLimits.  # noqa: E501
        :type ram_provisioned: int
        """
        if self.local_vars_configuration.client_side_validation and ram_provisioned is None:  # noqa: E501
            raise ValueError("Invalid value for `ram_provisioned`, must not be `None`")  # noqa: E501

        self._ram_provisioned = ram_provisioned

    @property
    def reservable_ips(self):
        """Gets the reservable_ips of this ResourceLimits.  # noqa: E501

        The maximum number of static public IP addresses that can be reserved by this customer across contracts.  # noqa: E501

        :return: The reservable_ips of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._reservable_ips

    @reservable_ips.setter
    def reservable_ips(self, reservable_ips):
        """Sets the reservable_ips of this ResourceLimits.

        The maximum number of static public IP addresses that can be reserved by this customer across contracts.  # noqa: E501

        :param reservable_ips: The reservable_ips of this ResourceLimits.  # noqa: E501
        :type reservable_ips: int
        """
        if self.local_vars_configuration.client_side_validation and reservable_ips is None:  # noqa: E501
            raise ValueError("Invalid value for `reservable_ips`, must not be `None`")  # noqa: E501

        self._reservable_ips = reservable_ips

    @property
    def reserved_ips_in_use(self):
        """Gets the reserved_ips_in_use of this ResourceLimits.  # noqa: E501

        The number of static public IP addresses in use.  # noqa: E501

        :return: The reserved_ips_in_use of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._reserved_ips_in_use

    @reserved_ips_in_use.setter
    def reserved_ips_in_use(self, reserved_ips_in_use):
        """Sets the reserved_ips_in_use of this ResourceLimits.

        The number of static public IP addresses in use.  # noqa: E501

        :param reserved_ips_in_use: The reserved_ips_in_use of this ResourceLimits.  # noqa: E501
        :type reserved_ips_in_use: int
        """
        if self.local_vars_configuration.client_side_validation and reserved_ips_in_use is None:  # noqa: E501
            raise ValueError("Invalid value for `reserved_ips_in_use`, must not be `None`")  # noqa: E501

        self._reserved_ips_in_use = reserved_ips_in_use

    @property
    def reserved_ips_on_contract(self):
        """Gets the reserved_ips_on_contract of this ResourceLimits.  # noqa: E501

        The maximum number of static public IP addresses that can be reserved for this contract.  # noqa: E501

        :return: The reserved_ips_on_contract of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._reserved_ips_on_contract

    @reserved_ips_on_contract.setter
    def reserved_ips_on_contract(self, reserved_ips_on_contract):
        """Sets the reserved_ips_on_contract of this ResourceLimits.

        The maximum number of static public IP addresses that can be reserved for this contract.  # noqa: E501

        :param reserved_ips_on_contract: The reserved_ips_on_contract of this ResourceLimits.  # noqa: E501
        :type reserved_ips_on_contract: int
        """
        if self.local_vars_configuration.client_side_validation and reserved_ips_on_contract is None:  # noqa: E501
            raise ValueError("Invalid value for `reserved_ips_on_contract`, must not be `None`")  # noqa: E501

        self._reserved_ips_on_contract = reserved_ips_on_contract

    @property
    def ssd_limit_per_contract(self):
        """Gets the ssd_limit_per_contract of this ResourceLimits.  # noqa: E501

        The maximum amount of solid state disk space (in MB) that can be provisioned under this contract.  # noqa: E501

        :return: The ssd_limit_per_contract of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._ssd_limit_per_contract

    @ssd_limit_per_contract.setter
    def ssd_limit_per_contract(self, ssd_limit_per_contract):
        """Sets the ssd_limit_per_contract of this ResourceLimits.

        The maximum amount of solid state disk space (in MB) that can be provisioned under this contract.  # noqa: E501

        :param ssd_limit_per_contract: The ssd_limit_per_contract of this ResourceLimits.  # noqa: E501
        :type ssd_limit_per_contract: int
        """
        if self.local_vars_configuration.client_side_validation and ssd_limit_per_contract is None:  # noqa: E501
            raise ValueError("Invalid value for `ssd_limit_per_contract`, must not be `None`")  # noqa: E501

        self._ssd_limit_per_contract = ssd_limit_per_contract

    @property
    def ssd_limit_per_volume(self):
        """Gets the ssd_limit_per_volume of this ResourceLimits.  # noqa: E501

        The maximum size (in MB) of an individual solid state disk volume.  # noqa: E501

        :return: The ssd_limit_per_volume of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._ssd_limit_per_volume

    @ssd_limit_per_volume.setter
    def ssd_limit_per_volume(self, ssd_limit_per_volume):
        """Sets the ssd_limit_per_volume of this ResourceLimits.

        The maximum size (in MB) of an individual solid state disk volume.  # noqa: E501

        :param ssd_limit_per_volume: The ssd_limit_per_volume of this ResourceLimits.  # noqa: E501
        :type ssd_limit_per_volume: int
        """
        if self.local_vars_configuration.client_side_validation and ssd_limit_per_volume is None:  # noqa: E501
            raise ValueError("Invalid value for `ssd_limit_per_volume`, must not be `None`")  # noqa: E501

        self._ssd_limit_per_volume = ssd_limit_per_volume

    @property
    def ssd_volume_provisioned(self):
        """Gets the ssd_volume_provisioned of this ResourceLimits.  # noqa: E501

        The amount of solid state disk space (in MB) that is currently provisioned.  # noqa: E501

        :return: The ssd_volume_provisioned of this ResourceLimits.  # noqa: E501
        :rtype: int
        """
        return self._ssd_volume_provisioned

    @ssd_volume_provisioned.setter
    def ssd_volume_provisioned(self, ssd_volume_provisioned):
        """Sets the ssd_volume_provisioned of this ResourceLimits.

        The amount of solid state disk space (in MB) that is currently provisioned.  # noqa: E501

        :param ssd_volume_provisioned: The ssd_volume_provisioned of this ResourceLimits.  # noqa: E501
        :type ssd_volume_provisioned: int
        """
        if self.local_vars_configuration.client_side_validation and ssd_volume_provisioned is None:  # noqa: E501
            raise ValueError("Invalid value for `ssd_volume_provisioned`, must not be `None`")  # noqa: E501

        self._ssd_volume_provisioned = ssd_volume_provisioned
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourceLimits):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResourceLimits):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class ApplicationLoadBalancerHttpRule(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'conditions': 'list[ApplicationLoadBalancerHttpRuleCondition]',

        'content_type': 'str',

        'drop_query': 'bool',

        'location': 'str',

        'name': 'str',

        'response_message': 'str',

        'status_code': 'int',

        'target_group': 'str',

        'type': 'str',
    }

    attribute_map = {

        'conditions': 'conditions',

        'content_type': 'contentType',

        'drop_query': 'dropQuery',

        'location': 'location',

        'name': 'name',

        'response_message': 'responseMessage',

        'status_code': 'statusCode',

        'target_group': 'targetGroup',

        'type': 'type',
    }

    def __init__(self, conditions=None, content_type=None, drop_query=None, location=None, name=None, response_message=None, status_code=None, target_group=None, type=None, local_vars_configuration=None):  # noqa: E501
        """ApplicationLoadBalancerHttpRule - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._conditions = None
        self._content_type = None
        self._drop_query = None
        self._location = None
        self._name = None
        self._response_message = None
        self._status_code = None
        self._target_group = None
        self._type = None
        self.discriminator = None

        if conditions is not None:
            self.conditions = conditions
        if content_type is not None:
            self.content_type = content_type
        if drop_query is not None:
            self.drop_query = drop_query
        if location is not None:
            self.location = location
        self.name = name
        if response_message is not None:
            self.response_message = response_message
        if status_code is not None:
            self.status_code = status_code
        if target_group is not None:
            self.target_group = target_group
        self.type = type


    @property
    def conditions(self):
        """Gets the conditions of this ApplicationLoadBalancerHttpRule.  # noqa: E501

        An array of items in the collection. The action will be executed only if each condition is met; the rule will always be applied if no conditions are set.  # noqa: E501

        :return: The conditions of this ApplicationLoadBalancerHttpRule.  # noqa: E501
        :rtype: list[ApplicationLoadBalancerHttpRuleCondition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this ApplicationLoadBalancerHttpRule.

        An array of items in the collection. The action will be executed only if each condition is met; the rule will always be applied if no conditions are set.  # noqa: E501

        :param conditions: The conditions of this ApplicationLoadBalancerHttpRule.  # noqa: E501
        :type conditions: list[ApplicationLoadBalancerHttpRuleCondition]
        """

        self._conditions = conditions

    @property
    def content_type(self):
        """Gets the content_type of this ApplicationLoadBalancerHttpRule.  # noqa: E501

        Specifies the content type and is valid only for 'STATIC' actions.  # noqa: E501

        :return: The content_type of this ApplicationLoadBalancerHttpRule.  # noqa: E501
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """Sets the content_type of this ApplicationLoadBalancerHttpRule.

        Specifies the content type and is valid only for 'STATIC' actions.  # noqa: E501

        :param content_type: The content_type of this ApplicationLoadBalancerHttpRule.  # noqa: E501
        :type content_type: str
        """

        self._content_type = content_type

    @property
    def drop_query(self):
        """Gets the drop_query of this ApplicationLoadBalancerHttpRule.  # noqa: E501

        Indicates whether the query part of the URI should be dropped and is valid only for 'REDIRECT' actions. Default value is 'FALSE', the redirect URI does not contain any query parameters.  # noqa: E501

        :return: The drop_query of this ApplicationLoadBalancerHttpRule.  # noqa: E501
        :rtype: bool
        """
        return self._drop_query

    @drop_query.setter
    def drop_query(self, drop_query):
        """Sets the drop_query of this ApplicationLoadBalancerHttpRule.

        Indicates whether the query part of the URI should be dropped and is valid only for 'REDIRECT' actions. Default value is 'FALSE', the redirect URI does not contain any query parameters.  # noqa: E501

        :param drop_query: The drop_query of this ApplicationLoadBalancerHttpRule.  # noqa: E501
        :type drop_query: bool
        """

        self._drop_query = drop_query

    @property
    def location(self):
        """Gets the location of this ApplicationLoadBalancerHttpRule.  # noqa: E501

        The location for the redirection; this parameter is mandatory and valid only for 'REDIRECT' actions.  # noqa: E501

        :return: The location of this ApplicationLoadBalancerHttpRule.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this ApplicationLoadBalancerHttpRule.

        The location for the redirection; this parameter is mandatory and valid only for 'REDIRECT' actions.  # noqa: E501

        :param location: The location of this ApplicationLoadBalancerHttpRule.  # noqa: E501
        :type location: str
        """

        self._location = location

    @property
    def name(self):
        """Gets the name of this ApplicationLoadBalancerHttpRule.  # noqa: E501

        The unique name of the Application Load Balancer HTTP rule.  # noqa: E501

        :return: The name of this ApplicationLoadBalancerHttpRule.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ApplicationLoadBalancerHttpRule.

        The unique name of the Application Load Balancer HTTP rule.  # noqa: E501

        :param name: The name of this ApplicationLoadBalancerHttpRule.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def response_message(self):
        """Gets the response_message of this ApplicationLoadBalancerHttpRule.  # noqa: E501

        The response message of the request; this parameter is mandatory for 'STATIC' actions.  # noqa: E501

        :return: The response_message of this ApplicationLoadBalancerHttpRule.  # noqa: E501
        :rtype: str
        """
        return self._response_message

    @response_message.setter
    def response_message(self, response_message):
        """Sets the response_message of this ApplicationLoadBalancerHttpRule.

        The response message of the request; this parameter is mandatory for 'STATIC' actions.  # noqa: E501

        :param response_message: The response_message of this ApplicationLoadBalancerHttpRule.  # noqa: E501
        :type response_message: str
        """

        self._response_message = response_message

    @property
    def status_code(self):
        """Gets the status_code of this ApplicationLoadBalancerHttpRule.  # noqa: E501

        The status code is for 'REDIRECT' and 'STATIC' actions only.   If the HTTP rule is 'REDIRECT' the valid values are: 301, 302, 303, 307, 308; default value is '301'.  If the HTTP rule is 'STATIC' the valid values are from the range 200-599; default value is '503'.  # noqa: E501

        :return: The status_code of this ApplicationLoadBalancerHttpRule.  # noqa: E501
        :rtype: int
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this ApplicationLoadBalancerHttpRule.

        The status code is for 'REDIRECT' and 'STATIC' actions only.   If the HTTP rule is 'REDIRECT' the valid values are: 301, 302, 303, 307, 308; default value is '301'.  If the HTTP rule is 'STATIC' the valid values are from the range 200-599; default value is '503'.  # noqa: E501

        :param status_code: The status_code of this ApplicationLoadBalancerHttpRule.  # noqa: E501
        :type status_code: int
        """

        self._status_code = status_code

    @property
    def target_group(self):
        """Gets the target_group of this ApplicationLoadBalancerHttpRule.  # noqa: E501

        The ID of the target group; this parameter is mandatory and is valid only for 'FORWARD' actions.  # noqa: E501

        :return: The target_group of this ApplicationLoadBalancerHttpRule.  # noqa: E501
        :rtype: str
        """
        return self._target_group

    @target_group.setter
    def target_group(self, target_group):
        """Sets the target_group of this ApplicationLoadBalancerHttpRule.

        The ID of the target group; this parameter is mandatory and is valid only for 'FORWARD' actions.  # noqa: E501

        :param target_group: The target_group of this ApplicationLoadBalancerHttpRule.  # noqa: E501
        :type target_group: str
        """

        self._target_group = target_group

    @property
    def type(self):
        """Gets the type of this ApplicationLoadBalancerHttpRule.  # noqa: E501

        The HTTP rule type.  # noqa: E501

        :return: The type of this ApplicationLoadBalancerHttpRule.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ApplicationLoadBalancerHttpRule.

        The HTTP rule type.  # noqa: E501

        :param type: The type of this ApplicationLoadBalancerHttpRule.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["FORWARD", "STATIC", "REDIRECT"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApplicationLoadBalancerHttpRule):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ApplicationLoadBalancerHttpRule):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class ApplicationLoadBalancerHttpRuleCondition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'condition': 'str',

        'key': 'str',

        'negate': 'bool',

        'type': 'str',

        'value': 'str',
    }

    attribute_map = {

        'condition': 'condition',

        'key': 'key',

        'negate': 'negate',

        'type': 'type',

        'value': 'value',
    }

    def __init__(self, condition=None, key=None, negate=None, type=None, value=None, local_vars_configuration=None):  # noqa: E501
        """ApplicationLoadBalancerHttpRuleCondition - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._condition = None
        self._key = None
        self._negate = None
        self._type = None
        self._value = None
        self.discriminator = None

        self.condition = condition
        if key is not None:
            self.key = key
        if negate is not None:
            self.negate = negate
        self.type = type
        if value is not None:
            self.value = value


    @property
    def condition(self):
        """Gets the condition of this ApplicationLoadBalancerHttpRuleCondition.  # noqa: E501

        The matching rule for the HTTP rule condition attribute; this parameter is mandatory for 'HEADER', 'PATH', 'QUERY', 'METHOD', 'HOST', and 'COOKIE' types. It must be 'null' if the type is 'SOURCE_IP'.  # noqa: E501

        :return: The condition of this ApplicationLoadBalancerHttpRuleCondition.  # noqa: E501
        :rtype: str
        """
        return self._condition

    @condition.setter
    def condition(self, condition):
        """Sets the condition of this ApplicationLoadBalancerHttpRuleCondition.

        The matching rule for the HTTP rule condition attribute; this parameter is mandatory for 'HEADER', 'PATH', 'QUERY', 'METHOD', 'HOST', and 'COOKIE' types. It must be 'null' if the type is 'SOURCE_IP'.  # noqa: E501

        :param condition: The condition of this ApplicationLoadBalancerHttpRuleCondition.  # noqa: E501
        :type condition: str
        """
        if self.local_vars_configuration.client_side_validation and condition is None:  # noqa: E501
            raise ValueError("Invalid value for `condition`, must not be `None`")  # noqa: E501
        allowed_values = ["EXISTS", "CONTAINS", "EQUALS", "MATCHES", "STARTS_WITH", "ENDS_WITH"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and condition not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `condition` ({0}), must be one of {1}"  # noqa: E501
                .format(condition, allowed_values)
            )

        self._condition = condition

    @property
    def key(self):
        """Gets the key of this ApplicationLoadBalancerHttpRuleCondition.  # noqa: E501

        The key can only be set when the HTTP rule condition type is 'COOKIES', 'HEADER', or 'QUERY'. For the type 'PATH', 'METHOD', 'HOST', or 'SOURCE_IP' the value must be 'null'.  # noqa: E501

        :return: The key of this ApplicationLoadBalancerHttpRuleCondition.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this ApplicationLoadBalancerHttpRuleCondition.

        The key can only be set when the HTTP rule condition type is 'COOKIES', 'HEADER', or 'QUERY'. For the type 'PATH', 'METHOD', 'HOST', or 'SOURCE_IP' the value must be 'null'.  # noqa: E501

        :param key: The key of this ApplicationLoadBalancerHttpRuleCondition.  # noqa: E501
        :type key: str
        """

        self._key = key

    @property
    def negate(self):
        """Gets the negate of this ApplicationLoadBalancerHttpRuleCondition.  # noqa: E501

        Specifies whether the condition should be negated; the default value is 'FALSE'.  # noqa: E501

        :return: The negate of this ApplicationLoadBalancerHttpRuleCondition.  # noqa: E501
        :rtype: bool
        """
        return self._negate

    @negate.setter
    def negate(self, negate):
        """Sets the negate of this ApplicationLoadBalancerHttpRuleCondition.

        Specifies whether the condition should be negated; the default value is 'FALSE'.  # noqa: E501

        :param negate: The negate of this ApplicationLoadBalancerHttpRuleCondition.  # noqa: E501
        :type negate: bool
        """

        self._negate = negate

    @property
    def type(self):
        """Gets the type of this ApplicationLoadBalancerHttpRuleCondition.  # noqa: E501

        The HTTP rule condition type.  # noqa: E501

        :return: The type of this ApplicationLoadBalancerHttpRuleCondition.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ApplicationLoadBalancerHttpRuleCondition.

        The HTTP rule condition type.  # noqa: E501

        :param type: The type of this ApplicationLoadBalancerHttpRuleCondition.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["HEADER", "PATH", "QUERY", "METHOD", "HOST", "COOKIE", "SOURCE_IP"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def value(self):
        """Gets the value of this ApplicationLoadBalancerHttpRuleCondition.  # noqa: E501

        This parameter is mandatory for the conditions 'CONTAINS', 'EQUALS', 'MATCHES', 'STARTS_WITH', 'ENDS_WITH', or if the type is 'SOURCE_IP'. Specify a valid CIDR. If the condition is 'EXISTS', the value must be 'null'.  # noqa: E501

        :return: The value of this ApplicationLoadBalancerHttpRuleCondition.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this ApplicationLoadBalancerHttpRuleCondition.

        This parameter is mandatory for the conditions 'CONTAINS', 'EQUALS', 'MATCHES', 'STARTS_WITH', 'ENDS_WITH', or if the type is 'SOURCE_IP'. Specify a valid CIDR. If the condition is 'EXISTS', the value must be 'null'.  # noqa: E501

        :param value: The value of this ApplicationLoadBalancerHttpRuleCondition.  # noqa: E501
        :type value: str
        """

        self._value = value
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApplicationLoadBalancerHttpRuleCondition):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ApplicationLoadBalancerHttpRuleCondition):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class LabelProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'key': 'str',

        'resource_href': 'str',

        'resource_id': 'str',

        'resource_type': 'str',

        'value': 'str',
    }

    attribute_map = {

        'key': 'key',

        'resource_href': 'resourceHref',

        'resource_id': 'resourceId',

        'resource_type': 'resourceType',

        'value': 'value',
    }

    def __init__(self, key=None, resource_href=None, resource_id=None, resource_type=None, value=None, local_vars_configuration=None):  # noqa: E501
        """LabelProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._key = None
        self._resource_href = None
        self._resource_id = None
        self._resource_type = None
        self._value = None
        self.discriminator = None

        if key is not None:
            self.key = key
        if resource_href is not None:
            self.resource_href = resource_href
        if resource_id is not None:
            self.resource_id = resource_id
        if resource_type is not None:
            self.resource_type = resource_type
        if value is not None:
            self.value = value


    @property
    def key(self):
        """Gets the key of this LabelProperties.  # noqa: E501

        A label key  # noqa: E501

        :return: The key of this LabelProperties.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this LabelProperties.

        A label key  # noqa: E501

        :param key: The key of this LabelProperties.  # noqa: E501
        :type key: str
        """

        self._key = key

    @property
    def resource_href(self):
        """Gets the resource_href of this LabelProperties.  # noqa: E501

        URL to the Resource (absolute path) on which the label is applied.  # noqa: E501

        :return: The resource_href of this LabelProperties.  # noqa: E501
        :rtype: str
        """
        return self._resource_href

    @resource_href.setter
    def resource_href(self, resource_href):
        """Sets the resource_href of this LabelProperties.

        URL to the Resource (absolute path) on which the label is applied.  # noqa: E501

        :param resource_href: The resource_href of this LabelProperties.  # noqa: E501
        :type resource_href: str
        """

        self._resource_href = resource_href

    @property
    def resource_id(self):
        """Gets the resource_id of this LabelProperties.  # noqa: E501

        The ID of the resource.  # noqa: E501

        :return: The resource_id of this LabelProperties.  # noqa: E501
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this LabelProperties.

        The ID of the resource.  # noqa: E501

        :param resource_id: The resource_id of this LabelProperties.  # noqa: E501
        :type resource_id: str
        """

        self._resource_id = resource_id

    @property
    def resource_type(self):
        """Gets the resource_type of this LabelProperties.  # noqa: E501

        The type of the resource on which the label is applied.  # noqa: E501

        :return: The resource_type of this LabelProperties.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this LabelProperties.

        The type of the resource on which the label is applied.  # noqa: E501

        :param resource_type: The resource_type of this LabelProperties.  # noqa: E501
        :type resource_type: str
        """

        self._resource_type = resource_type

    @property
    def value(self):
        """Gets the value of this LabelProperties.  # noqa: E501

        A label value  # noqa: E501

        :return: The value of this LabelProperties.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this LabelProperties.

        A label value  # noqa: E501

        :param value: The value of this LabelProperties.  # noqa: E501
        :type value: str
        """

        self._value = value
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LabelProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LabelProperties):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "6.1.9"

# import apis into sdk package
from ionoscloud.api.application_load_balancers_api import ApplicationLoadBalancersApi
from ionoscloud.api.backup_units_api import BackupUnitsApi
from ionoscloud.api.contract_resources_api import ContractResourcesApi
from ionoscloud.api.data_centers_api import DataCentersApi
from ionoscloud.api.firewall_rules_api import FirewallRulesApi
from ionoscloud.api.flow_logs_api import FlowLogsApi
from ionoscloud.api.ip_blocks_api import IPBlocksApi
from ionoscloud.api.images_api import ImagesApi
from ionoscloud.api.kubernetes_api import KubernetesApi
from ionoscloud.api.lans_api import LANsApi
from ionoscloud.api.labels_api import LabelsApi
from ionoscloud.api.load_balancers_api import LoadBalancersApi
from ionoscloud.api.locations_api import LocationsApi
from ionoscloud.api.nat_gateways_api import NATGatewaysApi
from ionoscloud.api.network_load_balancers_api import NetworkLoadBalancersApi
from ionoscloud.api.network_interfaces_api import NetworkInterfacesApi
from ionoscloud.api.private_cross_connects_api import PrivateCrossConnectsApi
from ionoscloud.api.requests_api import RequestsApi
from ionoscloud.api.servers_api import ServersApi
from ionoscloud.api.snapshots_api import SnapshotsApi
from ionoscloud.api.target_groups_api import TargetGroupsApi
from ionoscloud.api.templates_api import TemplatesApi
from ionoscloud.api.user_s3_keys_api import UserS3KeysApi
from ionoscloud.api.user_management_api import UserManagementApi
from ionoscloud.api.volumes_api import VolumesApi
from ionoscloud.api.__api import Api

# import ApiClient
from ionoscloud.api_client import ApiClient
from ionoscloud.configuration import Configuration
from ionoscloud.exceptions import OpenApiException
from ionoscloud.exceptions import ApiTypeError
from ionoscloud.exceptions import ApiValueError
from ionoscloud.exceptions import ApiKeyError
from ionoscloud.exceptions import ApiAttributeError
from ionoscloud.exceptions import ApiException
# import models into sdk package
from ionoscloud.models.application_load_balancer import ApplicationLoadBalancer
from ionoscloud.models.application_load_balancer_entities import ApplicationLoadBalancerEntities
from ionoscloud.models.application_load_balancer_forwarding_rule import ApplicationLoadBalancerForwardingRule
from ionoscloud.models.application_load_balancer_forwarding_rule_properties import ApplicationLoadBalancerForwardingRuleProperties
from ionoscloud.models.application_load_balancer_forwarding_rule_put import ApplicationLoadBalancerForwardingRulePut
from ionoscloud.models.application_load_balancer_forwarding_rules import ApplicationLoadBalancerForwardingRules
from ionoscloud.models.application_load_balancer_http_rule import ApplicationLoadBalancerHttpRule
from ionoscloud.models.application_load_balancer_http_rule_condition import ApplicationLoadBalancerHttpRuleCondition
from ionoscloud.models.application_load_balancer_properties import ApplicationLoadBalancerProperties
from ionoscloud.models.application_load_balancer_put import ApplicationLoadBalancerPut
from ionoscloud.models.application_load_balancers import ApplicationLoadBalancers
from ionoscloud.models.attached_volumes import AttachedVolumes
from ionoscloud.models.backup_unit import BackupUnit
from ionoscloud.models.backup_unit_properties import BackupUnitProperties
from ionoscloud.models.backup_unit_sso import BackupUnitSSO
from ionoscloud.models.backup_units import BackupUnits
from ionoscloud.models.balanced_nics import BalancedNics
from ionoscloud.models.cdroms import Cdroms
from ionoscloud.models.connectable_datacenter import ConnectableDatacenter
from ionoscloud.models.contract import Contract
from ionoscloud.models.contract_properties import ContractProperties
from ionoscloud.models.contracts import Contracts
from ionoscloud.models.cpu_architecture_properties import CpuArchitectureProperties
from ionoscloud.models.data_center_entities import DataCenterEntities
from ionoscloud.models.datacenter import Datacenter
from ionoscloud.models.datacenter_element_metadata import DatacenterElementMetadata
from ionoscloud.models.datacenter_properties import DatacenterProperties
from ionoscloud.models.datacenters import Datacenters
from ionoscloud.models.error import Error
from ionoscloud.models.error_message import ErrorMessage
from ionoscloud.models.firewall_rule import FirewallRule
from ionoscloud.models.firewall_rules import FirewallRules
from ionoscloud.models.firewallrule_properties import FirewallruleProperties
from ionoscloud.models.flow_log import FlowLog
from ionoscloud.models.flow_log_properties import FlowLogProperties
from ionoscloud.models.flow_log_put import FlowLogPut
from ionoscloud.models.flow_logs import FlowLogs
from ionoscloud.models.group import Group
from ionoscloud.models.group_entities import GroupEntities
from ionoscloud.models.group_members import GroupMembers
from ionoscloud.models.group_properties import GroupProperties
from ionoscloud.models.group_share import GroupShare
from ionoscloud.models.group_share_properties import GroupShareProperties
from ionoscloud.models.group_shares import GroupShares
from ionoscloud.models.group_users import GroupUsers
from ionoscloud.models.groups import Groups
from ionoscloud.models.ip_failover import IPFailover
from ionoscloud.models.image import Image
from ionoscloud.models.image_properties import ImageProperties
from ionoscloud.models.images import Images
from ionoscloud.models.info import Info
from ionoscloud.models.ip_block import IpBlock
from ionoscloud.models.ip_block_properties import IpBlockProperties
from ionoscloud.models.ip_blocks import IpBlocks
from ionoscloud.models.ip_consumer import IpConsumer
from ionoscloud.models.kubernetes_auto_scaling import KubernetesAutoScaling
from ionoscloud.models.kubernetes_cluster import KubernetesCluster
from ionoscloud.models.kubernetes_cluster_entities import KubernetesClusterEntities
from ionoscloud.models.kubernetes_cluster_for_post import KubernetesClusterForPost
from ionoscloud.models.kubernetes_cluster_for_put import KubernetesClusterForPut
from ionoscloud.models.kubernetes_cluster_properties import KubernetesClusterProperties
from ionoscloud.models.kubernetes_cluster_properties_for_post import KubernetesClusterPropertiesForPost
from ionoscloud.models.kubernetes_cluster_properties_for_put import KubernetesClusterPropertiesForPut
from ionoscloud.models.kubernetes_clusters import KubernetesClusters
from ionoscloud.models.kubernetes_maintenance_window import KubernetesMaintenanceWindow
from ionoscloud.models.kubernetes_node import KubernetesNode
from ionoscloud.models.kubernetes_node_metadata import KubernetesNodeMetadata
from ionoscloud.models.kubernetes_node_pool import KubernetesNodePool
from ionoscloud.models.kubernetes_node_pool_for_post import KubernetesNodePoolForPost
from ionoscloud.models.kubernetes_node_pool_for_put import KubernetesNodePoolForPut
from ionoscloud.models.kubernetes_node_pool_lan import KubernetesNodePoolLan
from ionoscloud.models.kubernetes_node_pool_lan_routes import KubernetesNodePoolLanRoutes
from ionoscloud.models.kubernetes_node_pool_properties import KubernetesNodePoolProperties
from ionoscloud.models.kubernetes_node_pool_properties_for_post import KubernetesNodePoolPropertiesForPost
from ionoscloud.models.kubernetes_node_pool_properties_for_put import KubernetesNodePoolPropertiesForPut
from ionoscloud.models.kubernetes_node_pools import KubernetesNodePools
from ionoscloud.models.kubernetes_node_properties import KubernetesNodeProperties
from ionoscloud.models.kubernetes_nodes import KubernetesNodes
from ionoscloud.models.label import Label
from ionoscloud.models.label_properties import LabelProperties
from ionoscloud.models.label_resource import LabelResource
from ionoscloud.models.label_resource_properties import LabelResourceProperties
from ionoscloud.models.label_resources import LabelResources
from ionoscloud.models.labels import Labels
from ionoscloud.models.lan import Lan
from ionoscloud.models.lan_entities import LanEntities
from ionoscloud.models.lan_nics import LanNics
from ionoscloud.models.lan_post import LanPost
from ionoscloud.models.lan_properties import LanProperties
from ionoscloud.models.lan_properties_post import LanPropertiesPost
from ionoscloud.models.lans import Lans
from ionoscloud.models.loadbalancer import Loadbalancer
from ionoscloud.models.loadbalancer_entities import LoadbalancerEntities
from ionoscloud.models.loadbalancer_properties import LoadbalancerProperties
from ionoscloud.models.loadbalancers import Loadbalancers
from ionoscloud.models.location import Location
from ionoscloud.models.location_properties import LocationProperties
from ionoscloud.models.locations import Locations
from ionoscloud.models.nat_gateway import NatGateway
from ionoscloud.models.nat_gateway_entities import NatGatewayEntities
from ionoscloud.models.nat_gateway_lan_properties import NatGatewayLanProperties
from ionoscloud.models.nat_gateway_properties import NatGatewayProperties
from ionoscloud.models.nat_gateway_put import NatGatewayPut
from ionoscloud.models.nat_gateway_rule import NatGatewayRule
from ionoscloud.models.nat_gateway_rule_properties import NatGatewayRuleProperties
from ionoscloud.models.nat_gateway_rule_protocol import NatGatewayRuleProtocol
from ionoscloud.models.nat_gateway_rule_put import NatGatewayRulePut
from ionoscloud.models.nat_gateway_rule_type import NatGatewayRuleType
from ionoscloud.models.nat_gateway_rules import NatGatewayRules
from ionoscloud.models.nat_gateways import NatGateways
from ionoscloud.models.network_load_balancer import NetworkLoadBalancer
from ionoscloud.models.network_load_balancer_entities import NetworkLoadBalancerEntities
from ionoscloud.models.network_load_balancer_forwarding_rule import NetworkLoadBalancerForwardingRule
from ionoscloud.models.network_load_balancer_forwarding_rule_health_check import NetworkLoadBalancerForwardingRuleHealthCheck
from ionoscloud.models.network_load_balancer_forwarding_rule_properties import NetworkLoadBalancerForwardingRuleProperties
from ionoscloud.models.network_load_balancer_forwarding_rule_put import NetworkLoadBalancerForwardingRulePut
from ionoscloud.models.network_load_balancer_forwarding_rule_target import NetworkLoadBalancerForwardingRuleTarget
from ionoscloud.models.network_load_balancer_forwarding_rule_target_health_check import NetworkLoadBalancerForwardingRuleTargetHealthCheck
from ionoscloud.models.network_load_balancer_forwarding_rules import NetworkLoadBalancerForwardingRules
from ionoscloud.models.network_load_balancer_properties import NetworkLoadBalancerProperties
from ionoscloud.models.network_load_balancer_put import NetworkLoadBalancerPut
from ionoscloud.models.network_load_balancers import NetworkLoadBalancers
from ionoscloud.models.nic import Nic
from ionoscloud.models.nic_entities import NicEntities
from ionoscloud.models.nic_properties import NicProperties
from ionoscloud.models.nic_put import NicPut
from ionoscloud.models.nics import Nics
from ionoscloud.models.no_state_meta_data import NoStateMetaData
from ionoscloud.models.pagination_links import PaginationLinks
from ionoscloud.models.peer import Peer
from ionoscloud.models.private_cross_connect import PrivateCrossConnect
from ionoscloud.models.private_cross_connect_properties import PrivateCrossConnectProperties
from ionoscloud.models.private_cross_connects import PrivateCrossConnects
from ionoscloud.models.remote_console_url import RemoteConsoleUrl
from ionoscloud.models.request import Request
from ionoscloud.models.request_metadata import RequestMetadata
from ionoscloud.models.request_properties import RequestProperties
from ionoscloud.models.request_status import RequestStatus
from ionoscloud.models.request_status_metadata import RequestStatusMetadata
from ionoscloud.models.request_target import RequestTarget
from ionoscloud.models.requests import Requests
from ionoscloud.models.resource import Resource
from ionoscloud.models.resource_entities import ResourceEntities
from ionoscloud.models.resource_groups import ResourceGroups
from ionoscloud.models.resource_limits import ResourceLimits
from ionoscloud.models.resource_properties import ResourceProperties
from ionoscloud.models.resource_reference import ResourceReference
from ionoscloud.models.resources import Resources
from ionoscloud.models.resources_users import ResourcesUsers
from ionoscloud.models.s3_bucket import S3Bucket
from ionoscloud.models.s3_key import S3Key
from ionoscloud.models.s3_key_metadata import S3KeyMetadata
from ionoscloud.models.s3_key_properties import S3KeyProperties
from ionoscloud.models.s3_keys import S3Keys
from ionoscloud.models.s3_object_storage_sso import S3ObjectStorageSSO
from ionoscloud.models.server import Server
from ionoscloud.models.server_entities import ServerEntities
from ionoscloud.models.server_properties import ServerProperties
from ionoscloud.models.servers import Servers
from ionoscloud.models.snapshot import Snapshot
from ionoscloud.models.snapshot_properties import SnapshotProperties
from ionoscloud.models.snapshots import Snapshots
from ionoscloud.models.target_group import TargetGroup
from ionoscloud.models.target_group_health_check import TargetGroupHealthCheck
from ionoscloud.models.target_group_http_health_check import TargetGroupHttpHealthCheck
from ionoscloud.models.target_group_properties import TargetGroupProperties
from ionoscloud.models.target_group_put import TargetGroupPut
from ionoscloud.models.target_group_target import TargetGroupTarget
from ionoscloud.models.target_groups import TargetGroups
from ionoscloud.models.target_port_range import TargetPortRange
from ionoscloud.models.template import Template
from ionoscloud.models.template_properties import TemplateProperties
from ionoscloud.models.templates import Templates
from ionoscloud.models.token import Token
from ionoscloud.models.type import Type
from ionoscloud.models.user import User
from ionoscloud.models.user_metadata import UserMetadata
from ionoscloud.models.user_post import UserPost
from ionoscloud.models.user_properties import UserProperties
from ionoscloud.models.user_properties_post import UserPropertiesPost
from ionoscloud.models.user_properties_put import UserPropertiesPut
from ionoscloud.models.user_put import UserPut
from ionoscloud.models.users import Users
from ionoscloud.models.users_entities import UsersEntities
from ionoscloud.models.volume import Volume
from ionoscloud.models.volume_properties import VolumeProperties
from ionoscloud.models.volumes import Volumes




# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class FirewallruleProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'icmp_code': 'int',

        'icmp_type': 'int',

        'ip_version': 'str',

        'name': 'str',

        'port_range_end': 'int',

        'port_range_start': 'int',

        'protocol': 'str',

        'source_ip': 'str',

        'source_mac': 'str',

        'target_ip': 'str',

        'type': 'str',
    }

    attribute_map = {

        'icmp_code': 'icmpCode',

        'icmp_type': 'icmpType',

        'ip_version': 'ipVersion',

        'name': 'name',

        'port_range_end': 'portRangeEnd',

        'port_range_start': 'portRangeStart',

        'protocol': 'protocol',

        'source_ip': 'sourceIp',

        'source_mac': 'sourceMac',

        'target_ip': 'targetIp',

        'type': 'type',
    }

    def __init__(self, icmp_code=None, icmp_type=None, ip_version=None, name=None, port_range_end=None, port_range_start=None, protocol=None, source_ip=None, source_mac=None, target_ip=None, type=None, local_vars_configuration=None):  # noqa: E501
        """FirewallruleProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._icmp_code = None
        self._icmp_type = None
        self._ip_version = None
        self._name = None
        self._port_range_end = None
        self._port_range_start = None
        self._protocol = None
        self._source_ip = None
        self._source_mac = None
        self._target_ip = None
        self._type = None
        self.discriminator = None

        self.icmp_code = icmp_code
        self.icmp_type = icmp_type
        self.ip_version = ip_version
        if name is not None:
            self.name = name
        if port_range_end is not None:
            self.port_range_end = port_range_end
        if port_range_start is not None:
            self.port_range_start = port_range_start
        self.protocol = protocol
        self.source_ip = source_ip
        self.source_mac = source_mac
        self.target_ip = target_ip
        if type is not None:
            self.type = type


    @property
    def icmp_code(self):
        """Gets the icmp_code of this FirewallruleProperties.  # noqa: E501

        Defines the allowed code (from 0 to 254) if protocol ICMP or ICMPv6 is chosen. Value null allows all codes.  # noqa: E501

        :return: The icmp_code of this FirewallruleProperties.  # noqa: E501
        :rtype: int
        """
        return self._icmp_code

    @icmp_code.setter
    def icmp_code(self, icmp_code):
        """Sets the icmp_code of this FirewallruleProperties.

        Defines the allowed code (from 0 to 254) if protocol ICMP or ICMPv6 is chosen. Value null allows all codes.  # noqa: E501

        :param icmp_code: The icmp_code of this FirewallruleProperties.  # noqa: E501
        :type icmp_code: int
        """
        if (self.local_vars_configuration.client_side_validation and
                icmp_code is not None and icmp_code > 254):  # noqa: E501
            raise ValueError("Invalid value for `icmp_code`, must be a value less than or equal to `254`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                icmp_code is not None and icmp_code < 0):  # noqa: E501
            raise ValueError("Invalid value for `icmp_code`, must be a value greater than or equal to `0`")  # noqa: E501

        self._icmp_code = icmp_code

    @property
    def icmp_type(self):
        """Gets the icmp_type of this FirewallruleProperties.  # noqa: E501

        Defines the allowed type (from 0 to 254) if the protocol ICMP or ICMPv6 is chosen. Value null allows all types.  # noqa: E501

        :return: The icmp_type of this FirewallruleProperties.  # noqa: E501
        :rtype: int
        """
        return self._icmp_type

    @icmp_type.setter
    def icmp_type(self, icmp_type):
        """Sets the icmp_type of this FirewallruleProperties.

        Defines the allowed type (from 0 to 254) if the protocol ICMP or ICMPv6 is chosen. Value null allows all types.  # noqa: E501

        :param icmp_type: The icmp_type of this FirewallruleProperties.  # noqa: E501
        :type icmp_type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                icmp_type is not None and icmp_type > 254):  # noqa: E501
            raise ValueError("Invalid value for `icmp_type`, must be a value less than or equal to `254`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                icmp_type is not None and icmp_type < 0):  # noqa: E501
            raise ValueError("Invalid value for `icmp_type`, must be a value greater than or equal to `0`")  # noqa: E501

        self._icmp_type = icmp_type

    @property
    def ip_version(self):
        """Gets the ip_version of this FirewallruleProperties.  # noqa: E501

        The IP version for this rule. If sourceIp or targetIp are specified, you can omit this value - the IP version will then be deduced from the IP address(es) used; if you specify it anyway, it must match the specified IP address(es). If neither sourceIp nor targetIp are specified, this rule allows traffic only for the specified IP version. If neither sourceIp, targetIp nor ipVersion are specified, this rule will only allow IPv4 traffic.  # noqa: E501

        :return: The ip_version of this FirewallruleProperties.  # noqa: E501
        :rtype: str
        """
        return self._ip_version

    @ip_version.setter
    def ip_version(self, ip_version):
        """Sets the ip_version of this FirewallruleProperties.

        The IP version for this rule. If sourceIp or targetIp are specified, you can omit this value - the IP version will then be deduced from the IP address(es) used; if you specify it anyway, it must match the specified IP address(es). If neither sourceIp nor targetIp are specified, this rule allows traffic only for the specified IP version. If neither sourceIp, targetIp nor ipVersion are specified, this rule will only allow IPv4 traffic.  # noqa: E501

        :param ip_version: The ip_version of this FirewallruleProperties.  # noqa: E501
        :type ip_version: str
        """
        allowed_values = [None,"IPv4", "IPv6"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and ip_version not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `ip_version` ({0}), must be one of {1}"  # noqa: E501
                .format(ip_version, allowed_values)
            )

        self._ip_version = ip_version

    @property
    def name(self):
        """Gets the name of this FirewallruleProperties.  # noqa: E501

        The name of the  resource.  # noqa: E501

        :return: The name of this FirewallruleProperties.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FirewallruleProperties.

        The name of the  resource.  # noqa: E501

        :param name: The name of this FirewallruleProperties.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def port_range_end(self):
        """Gets the port_range_end of this FirewallruleProperties.  # noqa: E501

        Defines the end range of the allowed port (from 1 to 65534) if the protocol TCP or UDP is chosen. Leave portRangeStart and portRangeEnd null to allow all ports.  # noqa: E501

        :return: The port_range_end of this FirewallruleProperties.  # noqa: E501
        :rtype: int
        """
        return self._port_range_end

    @port_range_end.setter
    def port_range_end(self, port_range_end):
        """Sets the port_range_end of this FirewallruleProperties.

        Defines the end range of the allowed port (from 1 to 65534) if the protocol TCP or UDP is chosen. Leave portRangeStart and portRangeEnd null to allow all ports.  # noqa: E501

        :param port_range_end: The port_range_end of this FirewallruleProperties.  # noqa: E501
        :type port_range_end: int
        """
        if (self.local_vars_configuration.client_side_validation and
                port_range_end is not None and port_range_end > 65534):  # noqa: E501
            raise ValueError("Invalid value for `port_range_end`, must be a value less than or equal to `65534`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                port_range_end is not None and port_range_end < 1):  # noqa: E501
            raise ValueError("Invalid value for `port_range_end`, must be a value greater than or equal to `1`")  # noqa: E501

        self._port_range_end = port_range_end

    @property
    def port_range_start(self):
        """Gets the port_range_start of this FirewallruleProperties.  # noqa: E501

        Defines the start range of the allowed port (from 1 to 65534) if protocol TCP or UDP is chosen. Leave portRangeStart and portRangeEnd value null to allow all ports.  # noqa: E501

        :return: The port_range_start of this FirewallruleProperties.  # noqa: E501
        :rtype: int
        """
        return self._port_range_start

    @port_range_start.setter
    def port_range_start(self, port_range_start):
        """Sets the port_range_start of this FirewallruleProperties.

        Defines the start range of the allowed port (from 1 to 65534) if protocol TCP or UDP is chosen. Leave portRangeStart and portRangeEnd value null to allow all ports.  # noqa: E501

        :param port_range_start: The port_range_start of this FirewallruleProperties.  # noqa: E501
        :type port_range_start: int
        """
        if (self.local_vars_configuration.client_side_validation and
                port_range_start is not None and port_range_start > 65534):  # noqa: E501
            raise ValueError("Invalid value for `port_range_start`, must be a value less than or equal to `65534`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                port_range_start is not None and port_range_start < 1):  # noqa: E501
            raise ValueError("Invalid value for `port_range_start`, must be a value greater than or equal to `1`")  # noqa: E501

        self._port_range_start = port_range_start

    @property
    def protocol(self):
        """Gets the protocol of this FirewallruleProperties.  # noqa: E501

        The protocol for the rule. Property cannot be modified after it is created (disallowed in update requests).  # noqa: E501

        :return: The protocol of this FirewallruleProperties.  # noqa: E501
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this FirewallruleProperties.

        The protocol for the rule. Property cannot be modified after it is created (disallowed in update requests).  # noqa: E501

        :param protocol: The protocol of this FirewallruleProperties.  # noqa: E501
        :type protocol: str
        """
        if self.local_vars_configuration.client_side_validation and protocol is None:  # noqa: E501
            raise ValueError("Invalid value for `protocol`, must not be `None`")  # noqa: E501
        allowed_values = ["TCP", "UDP", "ICMP", "ICMPv6", "ANY"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and protocol not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `protocol` ({0}), must be one of {1}"  # noqa: E501
                .format(protocol, allowed_values)
            )

        self._protocol = protocol

    @property
    def source_ip(self):
        """Gets the source_ip of this FirewallruleProperties.  # noqa: E501

        Only traffic originating from the respective IP address (or CIDR block) is allowed. Value null allows traffic from any IP address (according to the selected ipVersion).  # noqa: E501

        :return: The source_ip of this FirewallruleProperties.  # noqa: E501
        :rtype: str
        """
        return self._source_ip

    @source_ip.setter
    def source_ip(self, source_ip):
        """Sets the source_ip of this FirewallruleProperties.

        Only traffic originating from the respective IP address (or CIDR block) is allowed. Value null allows traffic from any IP address (according to the selected ipVersion).  # noqa: E501

        :param source_ip: The source_ip of this FirewallruleProperties.  # noqa: E501
        :type source_ip: str
        """

        self._source_ip = source_ip

    @property
    def source_mac(self):
        """Gets the source_mac of this FirewallruleProperties.  # noqa: E501

        Only traffic originating from the respective MAC address is allowed. Valid format: aa:bb:cc:dd:ee:ff. Value null allows traffic from any MAC address.  # noqa: E501

        :return: The source_mac of this FirewallruleProperties.  # noqa: E501
        :rtype: str
        """
        return self._source_mac

    @source_mac.setter
    def source_mac(self, source_mac):
        """Sets the source_mac of this FirewallruleProperties.

        Only traffic originating from the respective MAC address is allowed. Valid format: aa:bb:cc:dd:ee:ff. Value null allows traffic from any MAC address.  # noqa: E501

        :param source_mac: The source_mac of this FirewallruleProperties.  # noqa: E501
        :type source_mac: str
        """

        self._source_mac = source_mac

    @property
    def target_ip(self):
        """Gets the target_ip of this FirewallruleProperties.  # noqa: E501

        If the target NIC has multiple IP addresses, only the traffic directed to the respective IP address (or CIDR block) of the NIC is allowed. Value null allows traffic to any target IP address (according to the selected ipVersion).  # noqa: E501

        :return: The target_ip of this FirewallruleProperties.  # noqa: E501
        :rtype: str
        """
        return self._target_ip

    @target_ip.setter
    def target_ip(self, target_ip):
        """Sets the target_ip of this FirewallruleProperties.

        If the target NIC has multiple IP addresses, only the traffic directed to the respective IP address (or CIDR block) of the NIC is allowed. Value null allows traffic to any target IP address (according to the selected ipVersion).  # noqa: E501

        :param target_ip: The target_ip of this FirewallruleProperties.  # noqa: E501
        :type target_ip: str
        """

        self._target_ip = target_ip

    @property
    def type(self):
        """Gets the type of this FirewallruleProperties.  # noqa: E501

        The type of the firewall rule. If not specified, the default INGRESS value is used.  # noqa: E501

        :return: The type of this FirewallruleProperties.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this FirewallruleProperties.

        The type of the firewall rule. If not specified, the default INGRESS value is used.  # noqa: E501

        :param type: The type of this FirewallruleProperties.  # noqa: E501
        :type type: str
        """
        allowed_values = ["INGRESS", "EGRESS"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FirewallruleProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FirewallruleProperties):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class RequestTarget(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'status': 'str',

        'target': 'ResourceReference',
    }

    attribute_map = {

        'status': 'status',

        'target': 'target',
    }

    def __init__(self, status=None, target=None, local_vars_configuration=None):  # noqa: E501
        """RequestTarget - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._status = None
        self._target = None
        self.discriminator = None

        if status is not None:
            self.status = status
        if target is not None:
            self.target = target


    @property
    def status(self):
        """Gets the status of this RequestTarget.  # noqa: E501


        :return: The status of this RequestTarget.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this RequestTarget.


        :param status: The status of this RequestTarget.  # noqa: E501
        :type status: str
        """
        allowed_values = ["QUEUED", "RUNNING", "DONE", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def target(self):
        """Gets the target of this RequestTarget.  # noqa: E501


        :return: The target of this RequestTarget.  # noqa: E501
        :rtype: ResourceReference
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this RequestTarget.


        :param target: The target of this RequestTarget.  # noqa: E501
        :type target: ResourceReference
        """

        self._target = target
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RequestTarget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RequestTarget):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class NetworkLoadBalancerForwardingRuleTarget(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'health_check': 'NetworkLoadBalancerForwardingRuleTargetHealthCheck',

        'ip': 'str',

        'port': 'int',

        'weight': 'int',

        'proxy_protocol': 'str',
    }

    attribute_map = {

        'health_check': 'healthCheck',

        'ip': 'ip',

        'port': 'port',

        'weight': 'weight',

        'proxy_protocol': 'proxyProtocol',
    }

    def __init__(self, health_check=None, ip=None, port=None, weight=None, proxy_protocol='none', local_vars_configuration=None):  # noqa: E501
        """NetworkLoadBalancerForwardingRuleTarget - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._health_check = None
        self._ip = None
        self._port = None
        self._weight = None
        self._proxy_protocol = None
        self.discriminator = None

        if health_check is not None:
            self.health_check = health_check
        self.ip = ip
        self.port = port
        self.weight = weight
        if proxy_protocol is not None:
            self.proxy_protocol = proxy_protocol


    @property
    def health_check(self):
        """Gets the health_check of this NetworkLoadBalancerForwardingRuleTarget.  # noqa: E501


        :return: The health_check of this NetworkLoadBalancerForwardingRuleTarget.  # noqa: E501
        :rtype: NetworkLoadBalancerForwardingRuleTargetHealthCheck
        """
        return self._health_check

    @health_check.setter
    def health_check(self, health_check):
        """Sets the health_check of this NetworkLoadBalancerForwardingRuleTarget.


        :param health_check: The health_check of this NetworkLoadBalancerForwardingRuleTarget.  # noqa: E501
        :type health_check: NetworkLoadBalancerForwardingRuleTargetHealthCheck
        """

        self._health_check = health_check

    @property
    def ip(self):
        """Gets the ip of this NetworkLoadBalancerForwardingRuleTarget.  # noqa: E501

        The IP of the balanced target VM.  # noqa: E501

        :return: The ip of this NetworkLoadBalancerForwardingRuleTarget.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this NetworkLoadBalancerForwardingRuleTarget.

        The IP of the balanced target VM.  # noqa: E501

        :param ip: The ip of this NetworkLoadBalancerForwardingRuleTarget.  # noqa: E501
        :type ip: str
        """
        if self.local_vars_configuration.client_side_validation and ip is None:  # noqa: E501
            raise ValueError("Invalid value for `ip`, must not be `None`")  # noqa: E501

        self._ip = ip

    @property
    def port(self):
        """Gets the port of this NetworkLoadBalancerForwardingRuleTarget.  # noqa: E501

        The port of the balanced target service; valid range is 1 to 65535.  # noqa: E501

        :return: The port of this NetworkLoadBalancerForwardingRuleTarget.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this NetworkLoadBalancerForwardingRuleTarget.

        The port of the balanced target service; valid range is 1 to 65535.  # noqa: E501

        :param port: The port of this NetworkLoadBalancerForwardingRuleTarget.  # noqa: E501
        :type port: int
        """
        if self.local_vars_configuration.client_side_validation and port is None:  # noqa: E501
            raise ValueError("Invalid value for `port`, must not be `None`")  # noqa: E501

        self._port = port

    @property
    def weight(self):
        """Gets the weight of this NetworkLoadBalancerForwardingRuleTarget.  # noqa: E501

        Traffic is distributed in proportion to target weight, relative to the combined weight of all targets. A target with higher weight receives a greater share of traffic. Valid range is 0 to 256 and default is 1. Targets with weight of 0 do not participate in load balancing but still accept persistent connections. It is best to assign weights in the middle of the range to leave room for later adjustments.  # noqa: E501

        :return: The weight of this NetworkLoadBalancerForwardingRuleTarget.  # noqa: E501
        :rtype: int
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """Sets the weight of this NetworkLoadBalancerForwardingRuleTarget.

        Traffic is distributed in proportion to target weight, relative to the combined weight of all targets. A target with higher weight receives a greater share of traffic. Valid range is 0 to 256 and default is 1. Targets with weight of 0 do not participate in load balancing but still accept persistent connections. It is best to assign weights in the middle of the range to leave room for later adjustments.  # noqa: E501

        :param weight: The weight of this NetworkLoadBalancerForwardingRuleTarget.  # noqa: E501
        :type weight: int
        """
        if self.local_vars_configuration.client_side_validation and weight is None:  # noqa: E501
            raise ValueError("Invalid value for `weight`, must not be `None`")  # noqa: E501

        self._weight = weight

    @property
    def proxy_protocol(self):
        """Gets the proxy_protocol of this NetworkLoadBalancerForwardingRuleTarget.  # noqa: E501

        ProxyProtocol is used to set the proxy protocol version.  # noqa: E501

        :return: The proxy_protocol of this NetworkLoadBalancerForwardingRuleTarget.  # noqa: E501
        :rtype: str
        """
        return self._proxy_protocol

    @proxy_protocol.setter
    def proxy_protocol(self, proxy_protocol):
        """Sets the proxy_protocol of this NetworkLoadBalancerForwardingRuleTarget.

        ProxyProtocol is used to set the proxy protocol version.  # noqa: E501

        :param proxy_protocol: The proxy_protocol of this NetworkLoadBalancerForwardingRuleTarget.  # noqa: E501
        :type proxy_protocol: str
        """
        allowed_values = ["none", "v1", "v2", "v2ssl"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and proxy_protocol not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `proxy_protocol` ({0}), must be one of {1}"  # noqa: E501
                .format(proxy_protocol, allowed_values)
            )

        self._proxy_protocol = proxy_protocol
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NetworkLoadBalancerForwardingRuleTarget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NetworkLoadBalancerForwardingRuleTarget):
            return True

        return self.to_dict() != other.to_dict()
